==> zio-aws-route53resolver_3-5.17.155.2-sources.jar: zio/aws/route53resolver/model/Filter.scala <==
package zio.aws.route53resolver.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.route53resolver.model.primitives.{FilterValue, FilterName}
import scala.jdk.CollectionConverters.*
final case class Filter(
    name: Option[FilterName] = None,
    values: Option[Iterable[FilterValue]] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.route53resolver.model.Filter = {
    import Filter.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.route53resolver.model.Filter
      .builder()
      .optionallyWith(
        name.map(value => FilterName.unwrap(value): java.lang.String)
      )(_.name)
      .optionallyWith(
        values.map(value =>
          value.map { item =>
            FilterValue.unwrap(item): java.lang.String
          }.asJavaCollection
        )
      )(_.values)
      .build()
  }
  def asReadOnly: zio.aws.route53resolver.model.Filter.ReadOnly =
    zio.aws.route53resolver.model.Filter.wrap(buildAwsValue())
}
object Filter {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.route53resolver.model.Filter
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.route53resolver.model.Filter =
      zio.aws.route53resolver.model
        .Filter(name.map(value => value), values.map(value => value))
    def name: Option[FilterName]
    def values: Option[List[FilterValue]]
    def getName: ZIO[Any, AwsError, FilterName] =
      AwsError.unwrapOptionField("name", name)
    def getValues: ZIO[Any, AwsError, List[FilterValue]] =
      AwsError.unwrapOptionField("values", values)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.route53resolver.model.Filter
  ) extends zio.aws.route53resolver.model.Filter.ReadOnly {
    override val name: Option[FilterName] = scala
      .Option(impl.name())
      .map(value => zio.aws.route53resolver.model.primitives.FilterName(value))
    override val values: Option[List[FilterValue]] = scala
      .Option(impl.values())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.route53resolver.model.primitives.FilterValue(item)
        }.toList
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.route53resolver.model.Filter
  ): zio.aws.route53resolver.model.Filter.ReadOnly = new Wrapper(impl)
}

==> zio-aws-route53resolver_3-5.20.22.2-sources.jar: zio/aws/route53resolver/model/Filter.scala <==
package zio.aws.route53resolver.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.route53resolver.model.primitives.{FilterValue, FilterName}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class Filter(
    name: Optional[FilterName] = Optional.Absent,
    values: Optional[Iterable[FilterValue]] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.route53resolver.model.Filter = {
    import Filter.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.route53resolver.model.Filter
      .builder()
      .optionallyWith(
        name.map(value => FilterName.unwrap(value): java.lang.String)
      )(_.name)
      .optionallyWith(
        values.map(value =>
          value.map { item =>
            FilterValue.unwrap(item): java.lang.String
          }.asJavaCollection
        )
      )(_.values)
      .build()
  }
  def asReadOnly: zio.aws.route53resolver.model.Filter.ReadOnly =
    zio.aws.route53resolver.model.Filter.wrap(buildAwsValue())
}
object Filter {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.route53resolver.model.Filter
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.route53resolver.model.Filter =
      zio.aws.route53resolver.model
        .Filter(name.map(value => value), values.map(value => value))
    def name: Optional[FilterName]
    def values: Optional[List[FilterValue]]
    def getName: ZIO[Any, AwsError, FilterName] =
      AwsError.unwrapOptionField("name", name)
    def getValues: ZIO[Any, AwsError, List[FilterValue]] =
      AwsError.unwrapOptionField("values", values)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.route53resolver.model.Filter
  ) extends zio.aws.route53resolver.model.Filter.ReadOnly {
    override val name: Optional[FilterName] = zio.aws.core.internal
      .optionalFromNullable(impl.name())
      .map(value => zio.aws.route53resolver.model.primitives.FilterName(value))
    override val values: Optional[List[FilterValue]] = zio.aws.core.internal
      .optionalFromNullable(impl.values())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.route53resolver.model.primitives.FilterValue(item)
        }.toList
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.route53resolver.model.Filter
  ): zio.aws.route53resolver.model.Filter.ReadOnly = new Wrapper(impl)
}
